import react from 'react';
import { useState, useEffect } from 'react';
import { Map, Marker, ZoomControl } from 'pigeon-maps';
import { Geolocation } from '@awesome-cordova-plugins/geolocation';
import LiveOverlay from './live-overlay';

const LiveMap: react.FC = () => {
  const initialCenter: [number, number] = [44.73574, 6.18981];
  const initialZoom: number = 13;
  const [center, setCenter] = useState(initialCenter);
  const [position, setPosition] = useState(initialCenter);
  const [zoom, setZoom] = useState(initialZoom);

  useEffect(() => {
    Geolocation.getCurrentPosition().then((position) => {
      setCenter([position.coords.latitude, position.coords.longitude]);
      setPosition([position.coords.latitude, position.coords.longitude]);
    });
  }, []);

  return (
     <Map
      center={center}
      zoom={zoom}
      onBoundsChanged={({ center, zoom }) => {
        setCenter(center);
        setZoom(zoom);
      }}
      animate={true}
    >
      <ZoomControl />
      <Marker width={20} anchor={position} />
      <LiveOverlay
        coordinates={[
          [center[1], center[0]],
          [initialCenter[1], initialCenter[0]],
        ]}
        mapState={undefined}
        latLngToPixel={undefined}
        
      />
    </Map>
  );
};

export default LiveMap;
